import java.io.*;
import java.util.*;
import java.math.*;

//Problem "The segment and the circles"
//5th Internet Olympiad, advanced level, season 2008-2009.
//Problem Author:  Vladimir Ulyantsev
//Solution Author: Maxim Buzdalov, buzdalov@rain.ifmo.ru

//This solution uses only integer arithmetic (in one of the cases this is big integer arithmetic)
//to cope with precision loss problems.

public class circles_mb_integer {
    private static final int MAX_COORD = 1000000000;
    
    private static final void unsafeAssertion(boolean expression, String message) {
        if (!expression) {
            throw new AssertionError(message);
        }
    }
    
    private static final int sqrtLo(long value) {
        int min = 0, max = Integer.MAX_VALUE;
        while (max - min > 1) {
            // '(min + max) / 2' overflows
            int mid = max / 2 + min / 2 + (min % 2 + max % 2) / 2;
            long mid2 = (long) (mid) * mid;
            if (mid2 <= value) {
                min = mid;
            } else {
                max = mid;
            }
        }
        if (max == Integer.MAX_VALUE) {
            System.err.println("sqrtLo warning: very high input (" + value + ")");
        }
        return min;
    }
    
    private static final int sqrtHi(long value) {
        int min = 0, max = Integer.MAX_VALUE;
        while (max - min > 1) {
            // '(min + max) / 2' overflows
            int mid = max / 2 + min / 2 + (min % 2 + max % 2) / 2;
            long mid2 = (long) (mid) * mid;
            if (mid2 >= value) {
                max = mid;
            } else {
                min = mid;
            }
        }
        if (max == Integer.MAX_VALUE) {
            System.err.println("sqrtHi warning: very high input (" + value + ")");
        }
        return max;
    }

    public static final void main(String[] args) throws IOException {
        final boolean auxInfo = System.getProperty("circles.debug") != null;
        if (auxInfo) {
            System.setErr(new PrintStream(new FileOutputStream("debug.err", true)));
        }
        
        Scanner in = new Scanner(new File("circles.in"));
        int x1 = in.nextInt();
        int y1 = in.nextInt();
        int x2 = in.nextInt();
        int y2 = in.nextInt();
        unsafeAssertion(!in.hasNext(), "Extra input data");
        unsafeAssertion(Math.abs(x1) <= MAX_COORD, "x1 is out of bounds");
        unsafeAssertion(Math.abs(y1) <= MAX_COORD, "y1 is out of bounds");
        unsafeAssertion(Math.abs(x2) <= MAX_COORD, "x2 is out of bounds");
        unsafeAssertion(Math.abs(y2) <= MAX_COORD, "y2 is out of bounds");
        unsafeAssertion(x1 != x2 || y1 != y2, "The segment has zero length");
        in.close();
        
        long square = (long) (x1) * y2 - (long) (x2) * y1;

        if (square < 0) {
            int tmp = x1; 
            x1 = x2; 
            x2 = tmp;
            tmp = y1;
            y1 = y2;
            y2 = tmp;
            
            square = -square;
        }

        long dist2to1 = (long) (x1) * x1 + (long) (y1) * y1;
        long dist2to2 = (long) (x2) * x2 + (long) (y2) * y2;
        long length2 = (long) (x2 - x1) * (x2 - x1) + (long) (y2 - y1) * (y2 - y1);
        
        PrintWriter out = new PrintWriter("circles.out");
        
        if (square == 0) {
            //This is the case when the segment's line passes through the center.
            if ((long) (x1) * x2 + (long) (y1) * y2 > 0) {
                //Final case 1: The segment does not intersect the center.
                if (auxInfo) {
                    System.err.println("Case 1 of 5: The segment's line intersects the center, the segment does not");
                }

                int u = sqrtLo(Math.max(dist2to1, dist2to2));
                int v = sqrtHi(Math.min(dist2to1, dist2to2));
    
		System.err.println("u = " + u + " v = " + v);

                out.println(u - v + 1);
            } else {
                //Final case 2: The segment does intersect the center.
                if (auxInfo) {
                    System.err.println("Case 2 of 5: The segment intersects the center");
                }
                
                out.println(0L + sqrtLo(dist2to1) + sqrtLo(dist2to2));
            }
        } else {
            //The segment's line does not pass through the center.
            long smul1 = (long) (x1) * (x2 - x1) + (long) (y1) * (y2 - y1);
            long smul2 = (long) (x2) * (x2 - x1) + (long) (y2) * (y2 - y1);
            
            if (smul1 < 0 && smul2 > 0) {
                //The case when the closest point of a segment to the center IS NOT a segment's endpoint.
                //We need to find the distance from the center to the segment.
                //Unfortunately, using of double or perhaps even extended precision 
                //floating-point maths may result in precision loss.
                
                BigInteger square2 = BigInteger.valueOf(square).pow(2);
                BigInteger biLength2 = BigInteger.valueOf(length2);
                long dist2 = square2.divide(biLength2).longValue();
                int distDown = sqrtLo(dist2);
                
                int branch1 = sqrtLo(dist2to1) - distDown;
                int branch2 = sqrtLo(dist2to2) - distDown;
                
                if ((long) (distDown) * distDown == dist2 && square2.remainder(biLength2).signum() == 0) {
                    //Final case 4: The segment touches some integer circle.
                    if (auxInfo) {
                        System.err.println("Case 4 of 5: The segment touches the integer circle");
                    }
                    
                    out.println(1L + branch1 + branch2);
                } else {
                    //Final case 5: The segment doesn't touch any integer circles.
                    if (auxInfo) {
                        System.err.println("Case 5 of 5: The segment touches the non-integer circle");
                    }
                    
                    out.println(0L + branch1 + branch2);
                }
            } else {
                //Final case 3: The closest point of a segment to the center is a segment's endpoint. 
                if (auxInfo) {
                    System.err.println("Case 3 of 5: The segment's closest point to the center is a segment's endpoint");
                }
                
                out.println(sqrtLo(Math.max(dist2to1, dist2to2)) - sqrtHi(Math.min(dist2to1, dist2to2)) + 1);
            }
        }
        out.close();
    }
}
